#  Copyright (c) 2019 Markus Ressel
#  .
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#  .
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#  .
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

LONG_ARG_KEY_PREFIXES = ["—", "--"]
ABBREVIATED_ARG_KEY_PREFIXES = ['-']
ARG_NAMING_PREFIXES = LONG_ARG_KEY_PREFIXES + ABBREVIATED_ARG_KEY_PREFIXES

ARG_VALUE_SEPARATOR_CHAR = "="

QUOTE_CHARS = ['"', '\'']

KEY_NAMES = "names"
KEY_DESCRIPTION = "description"
KEY_ARGUMENTS = "arguments"
KEY_HELP_MESSAGE = "help_message"
KEY_PERMISSIONS = "permissions"
KEY_HIDDEN = "hidden"
